@@ -14,6 +14,7 @@ describe 'keystone' do
       :osfamily               => 'Debian',
       :operatingsystem        => 'Debian',
       :operatingsystemrelease => '7.0',
+      :os                     => { :name  => 'Debian', :family => 'Debian', :release => { :major => '7', :minor => '0' } },
     }))
   end
 
@@ -32,6 +33,8 @@ describe 'keystone' do
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
       'token_driver'                       => 'sql',
+      'password_hash_algorithm'            => '<SERVICE DEFAULT>',
+      'password_hash_rounds'               => '<SERVICE DEFAULT>',
       'revoke_driver'                      => 'sql',
       'revoke_by_id'                       => true,
       'cache_dir'                          => '/var/cache/keystone',
@@ -60,6 +63,7 @@ describe 'keystone' do
       'notification_transport_url'         => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_timeout_threshold' => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_rate'              => '<SERVICE DEFAULT>',
+      'amqp_durable_queues'                => '<SERVICE DEFAULT>',
       'admin_workers'                      => 20,
       'public_workers'                     => 20,
       'member_role_id'                     => '<SERVICE DEFAULT>',
@@ -85,6 +89,8 @@ describe 'keystone' do
       'catalog_type'                       => 'template',
       'token_provider'                     => 'uuid',
       'token_driver'                       => 'kvs',
+      'password_hash_algorithm'            => 'pbkdf2_sha512',
+      'password_hash_rounds'               => '29000',
       'revoke_driver'                      => 'kvs',
       'revoke_by_id'                       => false,
       'public_endpoint'                    => 'https://localhost:5000/v2.0/',
@@ -111,6 +117,7 @@ describe 'keystone' do
       'rabbit_heartbeat_timeout_threshold' => '60',
       'rabbit_heartbeat_rate'              => '10',
       'rabbit_ha_queues'                   => true,
+      'amqp_durable_queues'                => true,
       'default_domain'                     => 'other_domain',
       'member_role_id'                     => '123456789',
       'member_role_name'                   => 'othermember',
@@ -203,6 +210,14 @@ describe 'keystone' do
       is_expected.to contain_keystone_config('revoke/driver').with_value(param_hash['revoke_driver'])
     end
 
+    it 'should contain password_hash_algorithm' do
+      is_expected.to contain_keystone_config('identity/password_hash_algorithm').with_value(param_hash['password_hash_algorithm'])
+    end
+
+    it 'should contain password_hash_rounds' do
+      is_expected.to contain_keystone_config('identity/password_hash_rounds').with_value(param_hash['password_hash_rounds'])
+    end
+
     it 'should contain default revoke_by_id value ' do
       is_expected.to contain_keystone_config('token/revoke_by_id').with_value(param_hash['revoke_by_id'])
     end
@@ -231,6 +246,7 @@ describe 'keystone' do
     it 'should contain correct rabbit heartbeat configuration' do
       is_expected.to contain_keystone_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value(param_hash['rabbit_heartbeat_timeout_threshold'])
       is_expected.to contain_keystone_config('oslo_messaging_rabbit/heartbeat_rate').with_value(param_hash['rabbit_heartbeat_rate'])
+      is_expected.to contain_keystone_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(param_hash['amqp_durable_queues'])
     end
 
     it 'should remove max_token_size param by default' do
@@ -601,16 +617,18 @@ describe 'keystone' do
   describe 'configure cache memcache servers if set' do
     let :params do
       {
-        'admin_token'                  => 'service_token',
-        'memcache_servers'             => [ 'SERVER1:11211', 'SERVER2:11211' ],
-        'token_driver'                 => 'memcache',
-        'cache_backend'                => 'dogpile.cache.memcached',
-        'cache_backend_argument'       => ['url:SERVER3:12211'],
-        'cache_memcache_servers'       => [ 'SERVER3:11211', 'SERVER4:11211' ],
-        'memcache_dead_retry'          => '60',
-        'memcache_socket_timeout'      => '2',
-        'memcache_pool_maxsize'        => '1000',
-        'memcache_pool_unused_timeout' => '60',
+        'admin_token'                          => 'service_token',
+        'memcache_servers'                     => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'token_driver'                         => 'noop',
+        'cache_backend'                        => 'dogpile.cache.memcached',
+        'cache_backend_argument'               => ['url:SERVER3:12211'],
+        'cache_memcache_servers'               => [ 'SERVER3:11211', 'SERVER4:11211' ],
+        'memcache_dead_retry'                  => '60',
+        'memcache_socket_timeout'              => '2',
+        'memcache_pool_maxsize'                => '1000',
+        'memcache_pool_unused_timeout'         => '60',
+        'memcache_pool_connection_get_timeout' => '30',
+        'manage_backend_package'               => false,
       }
     end
 
@@ -627,27 +645,27 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
     it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
-    it { is_expected.to contain_package('python-memcache').with(
-      :name   => 'python-memcache',
-      :ensure => 'present'
-    ) }
+    it { is_expected.to contain_oslo__cache('keystone_config').with_manage_backend_package(false) }
+    it { is_expected.not_to contain_package('python-memcache') }
   end
 
   describe 'configure cache enabled if set' do
     let :params do
       {
-        'admin_token'                  => 'service_token',
-        'memcache_servers'             => [ 'SERVER1:11211', 'SERVER2:11211' ],
-        'token_driver'                 => 'memcache',
-        'cache_backend'                => 'dogpile.cache.memcached',
-        'cache_backend_argument'       => ['url:SERVER3:12211'],
-        'cache_enabled'                => false,
-        'cache_memcache_servers'       => [ 'SERVER3:11211', 'SERVER4:11211' ],
-        'memcache_dead_retry'          => '60',
-        'memcache_socket_timeout'      => '2',
-        'memcache_pool_maxsize'        => '1000',
-        'memcache_pool_unused_timeout' => '60',
+        'admin_token'                          => 'service_token',
+        'memcache_servers'                     => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'token_driver'                         => 'memcache',
+        'cache_backend'                        => 'dogpile.cache.memcached',
+        'cache_backend_argument'               => ['url:SERVER3:12211'],
+        'cache_enabled'                        => false,
+        'cache_memcache_servers'               => [ 'SERVER3:11211', 'SERVER4:11211' ],
+        'memcache_dead_retry'                  => '60',
+        'memcache_socket_timeout'              => '2',
+        'memcache_pool_maxsize'                => '1000',
+        'memcache_pool_unused_timeout'         => '60',
+        'memcache_pool_connection_get_timeout' => '30',
       }
     end
 
@@ -664,6 +682,7 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
     it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
     it { is_expected.to contain_package('python-memcache').with(
       :name   => 'python-memcache',
@@ -701,6 +720,7 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('<SERVICE DEFAULT>') }
   end
 
@@ -1170,7 +1190,8 @@ describe 'keystone' do
       @default_facts.merge(global_facts.merge({
         :osfamily               => 'RedHat',
         :operatingsystem        => 'RedHat',
-        :operatingsystemrelease => '7.0'
+        :operatingsystemrelease => '7.0',
+        :os                     => { :name  => 'RedHat', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
@@ -1190,7 +1211,8 @@ describe 'keystone' do
       @default_facts.merge(global_facts.merge({
         :osfamily               => 'Debian',
         :operatingsystem        => 'Debian',
-        :operatingsystemrelease => '7.0'
+        :operatingsystemrelease => '7.0',
+        :os                     => { :name  => 'Debian', :family => 'Debian', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
